@@ -7,38 +7,25 @@ knitr::opts_chunk$set(
 ## ----setup--------------------------------------------------------------------
 library(stplanr)
 
-## ---- echo=FALSE, eval=FALSE--------------------------------------------------
-#  # upload roads data
-#  if(!file.exists("roads_iow.Rds")) {
-#    download.file("https://github.com/ropensci/stplanr/releases/download/0.3.1/roads_iow.Rds", "roads_iow.Rds")
-#  }
-#  roads_iow = readRDS("roads_iow.Rds")
-#  sf::write_sf(roads_iow, "roads_iow.geojson")
-#  piggyback::pb_upload("roads_iow.geojson")
-
 ## ---- eval=FALSE--------------------------------------------------------------
-#  roads_iow = sf::read_sf("https://github.com/ropensci/stplanr/releases/download/0.3.1/roads_iow.geojson")
+#  remotes::install_github("itsleeds/geofabrik")
+#  library(geofabrik)
+#  roads_iow = get_geofabrik(name = "Isle of Wight")
+#  f = gf_filename("Isle of Wight")
+#  file.copy(f, "iow.pbf")
+#  options(osrm.server = "https://0.0.0.0:5000/", osrm.profile = "driving")
 
 ## -----------------------------------------------------------------------------
 library(osrm)
 
 ## ---- eval=FALSE--------------------------------------------------------------
-#  remotes::install_github("itsleeds/geofabrik")
-#  library(geofabrik)
-#  iow = get_geofabrik(name = "Isle of Wight")
-#  f = gf_filename("Isle of Wight")
-#  file.copy(f, "iow.pbf")
-#  options(osrm.server = "http://0.0.0.0:5000/", osrm.profile = "driving")
+#  l = pct::wight_lines_30
+#  p = line2points(l)
+#  r = osrm::osrmRoute(src = p[1, ], dst = p[2, ], returnclass = "sf", overview = "full")
+#  plot(r)
 
-## ---- echo=FALSE, eval=FALSE--------------------------------------------------
-#  if(!file.exists("iow.pbf"))
-#    download.file("http://download.geofabrik.de/europe/great-britain/england/isle-of-wight-latest.osm.pbf", "iow.pbf")
-
-## -----------------------------------------------------------------------------
-l = pct::wight_lines_30
-p = line2points(l)
-r = osrm::osrmRoute(src = p[1, ], dst = p[2, ], returnclass = "sf", overview = "full")
-plot(r)
+## ---- echo=FALSE--------------------------------------------------------------
+knitr::include_graphics("https://user-images.githubusercontent.com/1825120/86902789-577d1080-c106-11ea-91df-8d0180931562.png")
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  routes_osrm = route(l = l, route_fun = osrmRoute, returnclass = "sf", overview = "full")
